@@ -92,7 +92,7 @@ void AlarmTimeWidget::init(Mode mode, const QString& title)
     else
     {
         QBoxLayout* layout = new QVBoxLayout(this);
-        layout->setMargin(0);
+        layout->setContentsMargins(0, 0, 0, 0);
         layout->setSpacing(0);
         topWidget = new QGroupBox(title, this);
         layout->addWidget(topWidget);
@@ -102,7 +102,8 @@ void AlarmTimeWidget::init(Mode mode, const QString& title)
     connect(mButtonGroup, &ButtonGroup::buttonSet, this, &AlarmTimeWidget::slotButtonSet);
     QVBoxLayout* topLayout = new QVBoxLayout(topWidget);
     topLayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
-    topLayout->setMargin(title.isEmpty() ? 0 : style()->pixelMetric(QStyle::PM_DefaultChildMargin));
+    int dcm = title.isEmpty() ? 0 : style()->pixelMetric(QStyle::PM_DefaultChildMargin);
+    topLayout->setContentsMargins(dcm, dcm, dcm, dcm);
 
     // At time radio button/label
     mAtTimeRadio = new RadioButton((mDeferring ? i18nc("@option:radio", "Defer to date/time:") : i18nc("@option:radio", "At date/time:")), topWidget);
@@ -123,7 +124,7 @@ void AlarmTimeWidget::init(Mode mode, const QString& title)
     // Time edit box and Any time checkbox
     QWidget* timeBox = new QWidget(topWidget);
     QHBoxLayout* timeBoxHLayout = new QHBoxLayout(timeBox);
-    timeBoxHLayout->setMargin(0);
+    timeBoxHLayout->setContentsMargins(0, 0, 0, 0);
     timeBoxHLayout->setSpacing(2 * style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     mTimeEdit = new TimeEdit(timeBox);
     timeBoxHLayout->addWidget(mTimeEdit);
@@ -169,7 +170,7 @@ void AlarmTimeWidget::init(Mode mode, const QString& title)
 
     // Set up the layout, either narrow or wide
     QGridLayout* grid = new QGridLayout();
-    grid->setMargin(0);
+    grid->setContentsMargins(0, 0, 0, 0);
     topLayout->addLayout(grid);
     if (mDeferring)
     {
@@ -210,7 +211,7 @@ void AlarmTimeWidget::init(Mode mode, const QString& title)
         // Time zone selector
         mTimeZoneBox = new QWidget(topWidget);   // this is to control the QWhatsThis text display area
         QHBoxLayout* hlayout = new QHBoxLayout(mTimeZoneBox);
-        hlayout->setMargin(0);
+        hlayout->setContentsMargins(0, 0, 0, 0);
         QLabel* label = new QLabel(i18nc("@label:listbox", "Time zone:"), mTimeZoneBox);
         hlayout->addWidget(label);
         mTimeZone = new TimeZoneCombo(mTimeZoneBox);
@@ -240,7 +241,7 @@ void AlarmTimeWidget::init(Mode mode, const QString& title)
 void AlarmTimeWidget::setReadOnly(bool ro)
 {
     mAtTimeRadio->setReadOnly(ro);
-    mDateEdit->setOptions(ro ? KDateComboBox::Options(0) : KDateComboBox::EditDate | KDateComboBox::SelectDate | KDateComboBox::DatePicker);
+    mDateEdit->setOptions(ro ? KDateComboBox::Options{} : KDateComboBox::EditDate | KDateComboBox::SelectDate | KDateComboBox::DatePicker);
     mTimeEdit->setReadOnly(ro);
     if (mAnyTimeCheckBox)
         mAnyTimeCheckBox->setReadOnly(ro);
