@@ -747,15 +747,15 @@ bool CollectionControlModel::isEnabled(const Collection& collection, CalEvent::T
 {
     if (!collection.isValid()  ||  !instance()->collectionIds().contains(collection.id()))
         return false;
-    if (!AgentManager::self()->instance(collection.resource()).isValid())
+    Collection col = collection;
+    AkonadiModel::instance()->refresh(col);    // update with latest data
+    if (!AgentManager::self()->instance(col.resource()).isValid())
     {
         // The collection doesn't belong to a resource, so it can't be used.
         // Remove it from the list of collections.
         instance()->removeCollection(collection);
         return false;
     }
-    Collection col = collection;
-    AkonadiModel::instance()->refresh(col);    // update with latest data
     return col.hasAttribute<CollectionAttribute>()
        &&  col.attribute<CollectionAttribute>()->isEnabled(type);
 }
@@ -995,15 +995,16 @@ int CollectionControlModel::isWritableEnabled(const Akonadi::Collection& collect
 }
 int CollectionControlModel::isWritableEnabled(const Akonadi::Collection& collection, CalEvent::Type type, KACalendar::Compat& format)
 {
-    int writable = AkonadiModel::isWritable(collection, format);
+    Collection col(collection);
+    int writable = AkonadiModel::isWritable(col, format);
     if (writable == -1)
         return -1;
 
     // Check the collection's enabled status
-    if (!instance()->collectionIds().contains(collection.id())
-    ||  !collection.hasAttribute<CollectionAttribute>())
+    if (!instance()->collectionIds().contains(col.id())
+    ||  !col.hasAttribute<CollectionAttribute>())
         return -1;
-    if (!collection.attribute<CollectionAttribute>()->isEnabled(type))
+    if (!col.attribute<CollectionAttribute>()->isEnabled(type))
         return -1;
     return writable;
 }
@@ -1296,12 +1297,14 @@ Collection::List CollectionControlModel::enabledCollections(CalEvent::Type type,
     const QString mimeType = CalEvent::mimeType(type);
     const QList<Collection::Id> colIds = instance()->collectionIds();
     Collection::List result;
-    for (int i = 0, count = colIds.count();  i < count;  ++i)
+    for (Collection::Id colId : colIds)
     {
-        Collection c(colIds[i]);
-        AkonadiModel::instance()->refresh(c);    // update with latest data
-        if (c.contentMimeTypes().contains(mimeType)
-        &&  (!writable || ((c.rights() & writableRights) == writableRights)))
+        Collection c(colId);
+        if (!writable)
+            AkonadiModel::instance()->refresh(c);    // update with latest data
+        else if (AkonadiModel::isWritable(c) != 1)   // this refreshes 'c' (needed for mime type check)
+            continue;
+        if (c.contentMimeTypes().contains(mimeType))
             result += c;
     }
     return result;
@@ -1316,6 +1319,7 @@ Collection CollectionControlModel::collectionForResource(const QString& resource
     for (Collection::Id id : colIds)
     {
         Collection c(id);
+        AkonadiModel::instance()->refresh(c);    // update with latest data
         if (c.resource() == resourceId)
             return c;
     }
